@@ -1,4 +1,4 @@
-/* $Header: /cvs/gnome/gIDE/src/gide-windows.h,v 1.2 2000/04/16 04:59:58 jpr Exp $ */
+/* $Header: /cvs/gnome/gIDE/src/gide-windows.h,v 1.5 2001/07/20 04:23:21 jpr Exp $ */
 /* gIDE
  * Copyright (C) 1998-2000 JP Rosevear
  *
@@ -20,9 +20,14 @@
 #ifndef GIDE_WINDOWS_H
 #define GIDE_WINDOWS_H
 
-#include "gide.h"
+#include "gI_window.h"
+#include "e-splash.h"
 
-GideWindow *gide_window_new (void);
+/* Individual window functions */
+GideWindow *gide_window_new (ESplash *splash);
+
+/* Functions the apply to all windows */
+void gide_set_all_window_cfg_values (void);
 
 #endif
 
